Popular Extensions · Chart.js documentation
Author: chartjs

# Popular Extensions

Many extensions can be found on the Chart.js GitHub organization or on the npm registry.

## Charts

- chartjs-chart-financial - Adds financial chart types such as a candlestick.
- Chart.BarFunnel.js - Adds a bar funnel chart type.
- Chart.LinearGauge.js - Adds a linear gauge chart type.
- Chart.Smith.js - Adds a smith chart type.

In addition, many charts can be found on the npm registry.

## Plugins

- chartjs-plugin-annotation - Draws lines and boxes on chart area.
- chartjs-plugin-datalabels - Displays labels on data for any type of charts.
- chartjs-plugin-deferred - Defers initial chart update until chart scrolls into viewport.
- chartjs-plugin-draggable - Makes select chart elements draggable with the mouse.
- chartjs-plugin-stacked100 - Draws 100% stacked bar chart.
- chartjs-plugin-waterfall - Enables easy use of waterfall charts.
- chartjs-plugin-zoom - Enables zooming and panning on charts.

In addition, many plugins can be found on the npm registry.

## Integrations

### Angular (v2+)

- emn178/angular2-chartjs
- valor-software/ng2-charts

### Angular (v1)

- angular-chart.js
- tc-angular-chartjs
- angular-chartjs
- Angular Chart-js Directive

### React

- react-chartjs2
- react-chartjs-2

### Django

- Django JChart
- Django Chartjs

### Ruby on Rails

- chartjs-ror

### Laravel

- laravel-chartjs

### Vue.js

- vue-chartjs

### Java

- Chart.java

### GWT (Google Web toolkit)

- Charba

### Ember.js

- ember-cli-chart

# results matching ""

# No results matching ""